pylend
------
A Python library for consuming the LendingClub public REST API. 

.. image:: https://travis-ci.org/Webs961/pylend.svg?branch=master
    :target: https://travis-ci.org/Webs961/pylend

**Note**: This package is not written or supported by LendingClub. 

